pub struct Stroke {
pub paint: Paint,
pub width: f32,
pub cap: LineCap,
pub join: LineJoin,
}Expand description
Stroke style for drawing primitives. Includes join to control how corners are rendered in paths and rects; for line segments join is unused and defaults to Miter.
Fields
paint: Paintwidth: f32cap: LineCapjoin: LineJoinImplementations