Stroke

Struct Stroke 

pub struct Stroke {
    pub paint: Paint,
    pub width: f32,
    pub cap: LineCap,
    pub join: LineJoin,
}
Stroke style for drawing primitives. Includes join to control how corners are rendered in paths and rects; for line segments join is unused and defaults to Miter.

Fields

paint: Paintwidth: f32cap: LineCapjoin: LineJoin

Implementations

Source

impl Stroke

pub fn new(paint: impl Into<Paint>, width: f32) -> Self

pub fn with_cap(self, cap: LineCap) -> Self

pub fn with_join(self, join: LineJoin) -> Self